==> haskell-yesod-persistent-1.6.0.8-309-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-Fz9FlKhrRR9CA4l06MC3VU
key:                  yesod-persistent-1.6.0.8-Fz9FlKhrRR9CA4l06MC3VU
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  ff0cef1fa24f959e64a3b4a08a7c9832
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-Fz9FlKhrRR9CA4l06MC3VU
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    conduit-1.3.6-1no5QhYt5xqAMX9xy5osDY
    persistent-2.14.5.1-GOTkYQcuPcXEDBgOeuUnWD
    resource-pool-0.2.3.2-LQU0piIYTVWGxpRU2xNfiQ
    resourcet-1.2.6-E5mNqm21rnVD9a20HIq84b transformers-0.5.6.2
    yesod-core-1.6.26.0-6ULvCqVkKMtLfMe5UD8An0

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.8-310-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-GSRBB4fonpIC9pGGBILqBc
key:                  yesod-persistent-1.6.0.8-GSRBB4fonpIC9pGGBILqBc
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  8495ddf526f15920a4b0a5c2c22d5849
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-GSRBB4fonpIC9pGGBILqBc
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    conduit-1.3.6-ITaJCDyfp5cDfMMsLf8jTY
    persistent-2.14.5.1-I3P1zsg5uFl28NiJofWuM8
    resource-pool-0.2.3.2-LQU0piIYTVWGxpRU2xNfiQ
    resourcet-1.2.6-E5mNqm21rnVD9a20HIq84b transformers-0.5.6.2
    yesod-core-1.6.26.0-ElVJPExYeJXGRsVcZ3hkZC

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
